@@ -9,3 +9,6 @@ from winky.database_postgre import Postgre
 from winky.database_oracle import Oracle
 from winky.database_mysql import MySQL
 from time import sleep
+import urllib3
+
+urllib3.disable_warnings()
