@@ -80,67 +80,72 @@ class HTTPMessage:
             else:
                 self.__attach[os.path.basename(file)] = open(file, 'rb')
 
-    def post(self, url, port, metod="/", timeout=10):
+    def post(self, url, port, metod="/", timeout=10, allow_redirects=True):
         endpoint = f"{url}:{port}{metod}"
         response = requests.post(endpoint,
-                                 cookies={key: value.value  for key, value in self.__cookies.items()},
+                                 cookies={key: value.value for key, value in self.__cookies.items()},
                                  headers=self.__headers,
                                  params=self.__params,
                                  data=self.__body.encode(),
                                  timeout=timeout,
                                  verify=False,
                                  auth=self.__auth__,
-                                 files=self.__attach)
+                                 files=self.__attach,
+                                 allow_redirects=allow_redirects)
         return self.__make_response_message(response)
 
-    def put(self, url, port, metod="/", timeout=10):
+    def put(self, url, port, metod="/", timeout=10, allow_redirects=True):
         endpoint = f"{url}:{port}{metod}"
         response = requests.put(endpoint,
-                                cookies={key: value.value  for key, value in self.__cookies.items()},
+                                cookies={key: value.value for key, value in self.__cookies.items()},
                                 headers=self.__headers,
                                 params=self.__params,
                                 data=self.__body.encode(),
                                 timeout=timeout,
                                 verify=False,
                                 auth=self.__auth__,
-                                files=self.__attach)
+                                files=self.__attach,
+                                allow_redirects=allow_redirects)
         return self.__make_response_message(response)
 
-    def patch(self, url, port, metod="/", timeout=10):
+    def patch(self, url, port, metod="/", timeout=10, allow_redirects=True):
         endpoint = f"{url}:{port}{metod}"
         response = requests.patch(endpoint,
-                                  cookies={key: value.value  for key, value in self.__cookies.items()},
+                                  cookies={key: value.value for key, value in self.__cookies.items()},
                                   headers=self.__headers,
                                   params=self.__params,
                                   data=self.__body.encode(),
                                   timeout=timeout,
                                   verify=False,
                                   auth=self.__auth__,
-                                  files=self.__attach)
+                                  files=self.__attach,
+                                  allow_redirects=allow_redirects)
         return self.__make_response_message(response)
 
-    def delete(self, url, port, metod="/", timeout=10):
+    def delete(self, url, port, metod="/", timeout=10, allow_redirects=True):
         endpoint = f"{url}:{port}{metod}"
         response = requests.delete(endpoint,
-                                   cookies={key: value.value  for key, value in self.__cookies.items()},
+                                   cookies={key: value.value for key, value in self.__cookies.items()},
                                    headers=self.__headers,
                                    params=self.__params,
                                    data=self.__body.encode(),
                                    timeout=timeout,
                                    verify=False,
                                    auth=self.__auth__,
-                                   files=self.__attach)
+                                   files=self.__attach,
+                                   allow_redirects=allow_redirects)
         return self.__make_response_message(response)
 
-    def get(self, url, port, metod="/", timeout=10):
+    def get(self, url, port, metod="/", timeout=10, allow_redirects=True):
         endpoint = f"{url}:{port}{metod}"
         response = requests.get(endpoint,
-                                cookies={key: value.value  for key, value in self.__cookies.items()},
+                                cookies={key: value.value for key, value in self.__cookies.items()},
                                 headers=self.__headers,
                                 params=self.__params,
                                 timeout=timeout,
                                 verify=False,
-                                auth=self.__auth__)
+                                auth=self.__auth__,
+                                allow_redirects=allow_redirects)
         return self.__make_response_message(response)
 
     @staticmethod
