@@ -15,8 +15,8 @@ class TemplateJSON:
     def __delitem__(self, key):
         self._dictionary.pop(key)
 
-    def set_body_from_file(self, path):
-        with open(path, 'r') as file:
+    def set_body_from_file(self, path, encoding="UTF-8"):
+        with open(path, 'r', encoding=encoding) as file:
             self._dictionary = json.loads(file.read())
 
     def __get_single_value_json(self, name):
