@@ -6,8 +6,8 @@ class TemplateText:
     def __init__(self, body=""):
         self.__body = body
 
-    def set_body_from_file(self, path):
-        with open(path, 'r') as file:
+    def set_body_from_file(self, path, encoding="UTF-8"):
+        with open(path, 'r', encoding=encoding) as file:
             self.__body = file.read()
 
     @property
